@@ -68,7 +68,7 @@ Convert to Hankaku Katakana  or  Toggle Katakana <=> Hankaku Katakana Mode"
        skk-nicola-visit-nicola-website (module-installed-p 'browse-url)])))
 
 (static-cond
- ((eq skk-emacs-type 'xemacs)
+ ((featurep 'xemacs)
   (add-hook 'skk-mode-hook
 	    #'(lambda ()
 		(add-submenu
@@ -83,7 +83,8 @@ Convert to Hankaku Katakana  or  Toggle Katakana <=> Hankaku Katakana Mode"
      map
      '("menu-bar" "SKK")
      skk-kanagaki-menu-items))
-  (static-when (memq skk-emacs-type '(mule5 mule6))
+  (static-when (and (string-match "^GNU" (emacs-version))
+		    (>= emacs-major-version 21))
     (setq skk-e21-menu-resource-ja
 	  (append
 	   skk-e21-menu-resource-ja
@@ -111,9 +112,6 @@ Convert to Hankaku Katakana  or  Toggle Katakana <=> Hankaku Katakana Mode"
 	     ("Visit NIHONGO-NYURYOKU CONSORTIUM Web Site"
 	      . "$BF|K\8lF~NO%3%s%=!<%7%"%`$N%5%$%H$X(B")))))))
 
-(require 'product)
-(product-provide
-    (provide 'skk-kanagaki-menu)
-  (require 'skk-version))
+(provide 'skk-kanagaki-menu)
 
 ;;; skk-kanagaki-menu.el ends here
