@@ -62,7 +62,8 @@
 $BByE@$HH>ByE@$rF~NO$9$k$?$a$N%k!<%k!#(B")
 
 (defconst skk-kanagaki-print-help-function
-  (cond ((memq skk-emacs-type '(mule6))
+  (cond ((and (string-match "^GNU" (emacs-version))
+	      (>= emacs-major-version 23))
 	 #'help-print-return-message)
 	(t
 	 #'print-help-return-message)))
@@ -254,7 +255,7 @@
     (with-current-buffer skk-isearch-current-buffer
       (skk-isearch-delete-char arg)))
    (t
-    (delete-backward-char arg)))
+    (delete-char (- 0 arg))))
   ;;
   (when skk-dcomp-activate
     (skk-dcomp-after-delete-backward-char)))
@@ -288,9 +289,6 @@
    (t
     nil)))
 
-(require 'product)
-(product-provide
-    (provide 'skk-kanagaki-util)
-  (require 'skk-version))
+(provide 'skk-kanagaki-util)
 
 ;;; skk-kanagaki-util.el ends here
