@@ -535,9 +535,6 @@ XFree86 $B>e$G;HMQ$9$k>l9g!"(B $BNc$($P$3$NCM$r(B [henkan]  (XEmacs $B$G$O
    (t
     ad-do-it)))
 
-(require 'product)
-(product-provide
-    (provide 'skk-kanagaki)
-  (require 'skk-version))
+(provide 'skk-kanagaki)
 
 ;;; skk-kanagaki.el ends here
