@@ -204,9 +204,6 @@ ANSI Dvorak $BG[Ns%-!<%\!<%I$G(B NICOLA $BF~NO$9$k$?$a$N4pK\%k!<%k!#(B")
 
 (require 'skk-nicola)
 
-(require 'product)
-(product-provide
-    (provide 'skk-nicola-dvorak)
-  (require 'skk-version))
+(provide 'skk-nicola-dvorak)
 
 ;;; skk-nicola-dvorak.el ends here
