@@ -50,7 +50,8 @@
 (eval-and-compile
   (require 'skk-kanagaki))
 
-(static-when (memq skk-emacs-type '(mule5 mule6))
+(static-when (and (string-match "^GNU" (emacs-version))
+		  (>= emacs-major-version 21))
   (eval-and-compile
     (require 'skk-e21)))
 
@@ -89,15 +90,15 @@
   :group 'skk-nicola)
 
 (defcustom skk-nicola-rshift-keys
-  (nconc '(" ")
-	 (list (cond
-		((eq system-type 'windows-nt)
-		 [convert])
-		((eq skk-emacs-type 'xemacs)
-		 [henkan-mode])
-		(t
-		 ;; Emacs 20.3 or later
-		 [henkan])))) "\
+  (append '(" ")
+	  (list (cond
+		 ((eq system-type 'windows-nt)
+		  [convert])
+		 ((featurep 'xemacs)
+		  [henkan-mode])
+		 (t
+		  ;; Emacs 20.3 or later
+		  [henkan])))) "\
 *$B1&?F;X%-!<$H$7$F;H$&%-!<!#(B"
   :type `(repeat
 	  ,(if (get 'key-sequence 'widget-type)
@@ -461,12 +462,12 @@
 	(call-interactively 'self-insert-command t))
     ;; else
     (let ((last (static-cond
-		 ((eq skk-emacs-type 'xemacs)
+		 ((featurep 'xemacs)
 		  (event-key last-command-event))
 		 (t
 		  last-command-event)))
 	  (next (static-cond
-		 ((eq skk-emacs-type 'xemacs)
+		 ((featurep 'xemacs)
 		  (event-key (next-command-event)))
 		 (t
 		  (next-command-event))))
@@ -575,7 +576,7 @@
 (defun skk-nicola-event-to-key (event)
   "EVENT $B$rH/@8$9$k%-!<$r<hF@$9$k!#(B"
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (let ((char (event-to-character event)))
       (if (characterp char)
 	  char
@@ -1084,9 +1085,6 @@ ARG $B$rM?$($i$l$?>l9g$O$=$N?t$@$1J8;zNs$rO"7k$7$FF~NO$9$k!#(B"
 (put 'skk-nicola-self-insert-lshift 'isearch-command t)
 (put 'skk-nicola-self-insert-rshift 'isearch-command t)
 
-(require 'product)
-(product-provide
-    (provide 'skk-nicola)
-  (require 'skk-version))
+(provide 'skk-nicola)
 
 ;;; skk-nicola.el ends here
