@@ -1,14 +1,14 @@
 ;;; skk-annotation.el --- SKK annotation $B4XO"%W%m%0%i%`(B -*- coding: iso-2022-jp -*-
 
 ;; Copyright (C) 2000, 2001 NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
-;; Copyright (C) 2000-2008  SKK Development Team <skk@ring.gr.jp>
+;; Copyright (C) 2000-2010  SKK Development Team <skk@ring.gr.jp>
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-annotation.el,v 1.146 2010/01/27 03:02:48 skk-cvs Exp $
+;; Version: $Id: skk-annotation.el,v 1.159 2010/08/27 10:42:17 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Oct. 27, 2000.
-;; Last Modified: $Date: 2010/01/27 03:02:48 $
+;; Last Modified: $Date: 2010/08/27 10:42:17 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -147,7 +147,7 @@
 ;;
 ;;    http://ftp.debian.org/debian/pool/main/w/w3-url-e21/
 ;;
-;;    $B$J$I$+$i:G?7(B *.orig.tar.gz $B$r<hF@$7$F%$%s%9%H!<%k$7$^$9!#(B
+;;    $B$J$I$+$i?7$7$a$N(B *.orig.tar.gz $B$r<hF@$7$F%$%s%9%H!<%k$7$^$9!#(B
 ;;
 ;;    XEmacs $B$N>l9g!"(B xemacs-sumo $BCf$N(B w3 $B$K4^$^$l$k(B url.el $B$,FI$_9~$^$l$F$7$^(B
 ;;    $B$&$H@5$7$/5!G=$7$J$$$N$G!"Cm0U$7$F$/$@$5$$!#(B
@@ -233,7 +233,7 @@
 	     (= emacs-major-version 20))
     (defalias 'skk-tooltip-show-at-point 'ignore)))
 
-(static-when (eq skk-emacs-type 'xemacs)
+(static-when (featurep 'xemacs)
   (require 'skk-xemacs))
 
 (unless skk-annotation-mode-map
@@ -332,7 +332,9 @@
 	 (list (list copy-command browse-command))
 	 event key command urls note cache char digit)
     (while (and list
-		(or (eq this-command 'skk-annotation-wikipedia-region)
+		(or (memq this-command
+			  '(skk-annotation-wikipedia-region-or-at-point
+			    skk-annotation-wikipedia-region))
 		    (eq skk-henkan-mode 'active))
 		(if digit
 		    t
@@ -351,7 +353,9 @@
 		      ;; Return value of the following expression is important.
 		      (or (memq command list)
 			  (eq command 'digit-argument)
-			  (eq command 'skk-annotation-wikipedia-region)
+			  (memq command
+				'(skk-annotation-wikipedia-region-or-at-point
+				  skk-annotation-wikipedia-region))
 			  (equal (key-description key)
 				 (key-description
 				  skk-annotation-wikipedia-key))))
@@ -419,7 +423,9 @@
 		   event nil))
 	    ((or (equal (key-description key)
 			(key-description skk-annotation-wikipedia-key))
-		 (eq command 'skk-annotation-wikipedia-region))
+		 (memq command
+		       '(skk-annotation-wikipedia-region-or-at-point
+			 skk-annotation-wikipedia-region)))
 	     (setq sources
 		   (if (and digit
 			    (> digit 0)
@@ -454,23 +460,27 @@
 		      (skk-in-minibuffer-p))))
     (unless skk-annotation-wikipedia-message
       (let* ((key (key-description skk-annotation-wikipedia-key))
-	     (string (format "{prefix %s}" (if (equal key "TAB")
-					       "C-i"
-					     key)))
+	     (string "{$B$I$N(BWiki?}")
 	     (i 0)
 	     source)
+	(when (equal key "TAB")
+	  (setq key "C-i"))
 	(while (setq source (nth i skk-annotation-wikipedia-sources))
-	  (setq string (format "%s[C-%d]%s" string (1+ i) source))
+	  (setq string (format "%s[C-%d %s]%s " string (1+ i) key source))
 	  (setq i (1+ i)))
 	(setq skk-annotation-wikipedia-message string)))
     (unless skk-annotation-message
-      (let* ((key-copy (or (key-description skk-annotation-copy-key)
-			   "$BL$Dj5A(B"))
-	     (key-browse (or (key-description skk-annotation-browse-key)
-			     "$BL$Dj5A(B")))
+      (let ((key-copy (or (key-description skk-annotation-copy-key)
+			  "$BL$Dj5A(B"))
+	    (key-wiki (or (key-description skk-annotation-wikipedia-key)
+			  "$BL$Dj5A(B"))
+	    (key-browse (or (key-description skk-annotation-browse-key)
+			    "$BL$Dj5A(B")))
+	(when (equal key-wiki "TAB")
+	  (setq key-wiki "C-i"))
 	(setq skk-annotation-message
-	      (format "{$B%"%N%F!<%7%g%s(B}[%s]$B%3%T!<(B[%s]URL$B%V%i%&%:(B"
-		      key-copy key-browse))))
+	      (format "{$B%"%N%F!<%7%g%sA`:n(B}[%s]$B%3%T!<$9$k(B [%s]URL$B$r8+$D$1$k(B [%s]$B%G%U%)%k%H(BWiki$B$+$iH4?h(B"
+		      key-copy key-browse key-wiki))))
     (condition-case nil
 	(cond ((eq situation 'annotation)
 	       (if (skk-sit-for skk-verbose-wait)
@@ -478,10 +488,10 @@
 		     (catch 'loop
 		       (while (< i 20)
 			 (message "%s" skk-annotation-message)
-			 (unless (skk-sit-for 5.5)
+			 (unless (skk-sit-for skk-verbose-message-interval)
 			   (throw 'loop nil))
 			 (message "%s" skk-annotation-wikipedia-message)
-			 (unless (skk-sit-for 5.5)
+			 (unless (skk-sit-for skk-verbose-message-interval)
 			   (throw 'loop nil))
 			 (setq i (1+ i))))
 		     (message nil))
@@ -614,7 +624,7 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
     (skk-annotation-setup)
     (let* ((plist (append
 		   '(intangible t read-only t)
-		   (static-if (eq skk-emacs-type 'xemacs)
+		   (static-if (featurep 'xemacs)
 		       '(start-closed t end-open t)
 		     '(front-sticky t rear-nonsticky t))))
 	   (wholestring (nth 2 skk-annotation-target-data))
@@ -849,22 +859,42 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
     ;; sources $B$K;XDj$5$l$?=gHV$K;2>H$9$k(B
     (if (catch 'skk-annotation-wikipedia-suspended
 	  (save-match-data
-	    (while (and (not note)
+	    (while (and (or (not note) (equal note ""))
 			sources)
 	      (setq source (car sources))
 	      ;; Wiktionary $B$G$O$=$N$^$^!"(BWikipedia $B$G$OBh(B 1 $BJ8;z$N$_(B upcase
 	      (setq note (skk-annotation-wikipedia-1 word source
 						     (= 1 (length sources))))
+	      (when (equal note "")
+		(setq note nil))
 	      ;;
 	      (when (and (null note)
 			 (memq source '(en.wiktionary ja.wiktionary))
 			 (skk-ascii-char-p (aref word 0))
 			 (not (skk-lower-case-p (aref word 0))))
 		;; Wiktionary $B$G$9$Y$F(B downcase $B$9$k>l9g(B
+		;; e.g. FOO or Foo -> foo
 		(setq note (skk-annotation-wikipedia-1
 			    (downcase word)
 			    source
-			    (= 1 (length sources)))))
+			    (= 1 (length sources))))
+		(when (equal note "")
+		  (setq note nil)))
+	      ;;
+	      (sleep-for 0.01) ; $B$3$l$,$J$$$H;_$^$k$3$H$"$j(B
+	      ;;
+	      (when (and (null note)
+			 (skk-ascii-char-p (aref word 0))
+			 (>= (length word) 2)
+			 (skk-lower-case-p (aref word 1)))
+		;; $B$9$Y$F(B upcase $B$9$k>l9g(B
+		;; e.g. skk or Skk -> SKK
+		(setq note (skk-annotation-wikipedia-1
+			    (upcase word)
+			    source
+			    (= 1 (length sources))))
+		(when (equal note "")
+		  (setq note nil)))
 	      ;;
 	      (setq string (format (if (string= "" string)
 				       "%s%s"
@@ -914,10 +944,10 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 	 (append '(("sup" . skk-annotation-wikipedia-clean-sup)
 		   ("sub" . skk-annotation-wikipedia-clean-sub))
 		 html2text-format-tag-list))
-	buf buffer note)
+	buf buffer)
     (if (get-buffer cache-buffer)
 	(with-current-buffer cache-buffer
-	  (setq note (buffer-string)))
+	  (buffer-string))
       ;; $B%-%c%C%7%e$,$J$$>l9g(B
       (setq buffer (url-retrieve (skk-annotation-generate-url
 				  "http://%s.org/wiki/%s"
@@ -928,7 +958,7 @@ no-previous-annotation $B$r;XDj$9$k$H(B \(C-u M-x skk-annotation-add $B$G;XDj
 	(setq buf (catch 'skk-annotation-wikipedia-retrieved
 		    (condition-case nil
 			(sleep-for 0.01)
-		      ((error)
+		      ((error quit)
 		       (kill-buffer buffer)
 		       (throw 'skk-annotation-wikipedia-suspended
 			      source))))))
@@ -1147,18 +1177,13 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 	      (erase-buffer)
 	    (setq aimai
 		  (save-excursion
-		    (re-search-forward "<a href=\"/wiki/Wikipedia:\
-\\(%E6%9B%96%E6%98%A7%E3%81%95%E5%9B%9E%E9%81%BF\\|Disambiguation\\)\""
-				       nil t)))
-	    (search-forward "<!-- start content -->" nil t)
-	    (delete-region (point-min) (point))
-	    ;; <div> $B$r=|5n$9$k(B
-	    (skk-annotation-wikipedia-remove-nested "<div.+>" "</div>")
+		    (re-search-forward "\
+^wgCategories=.+\\($B[#Kf$52sHr(B\\|[Dd]isambiguation\\).+$" nil t)))
 	    ;; <span> $B$r=|5n$9$k(B
 	    (setq point nil)
 	    (goto-char (point-min))
-	    (while (re-search-forward
-		    "<span class=\"\\(.+audiolink.+\\|editsection\\)\".*>" nil t)
+	    (while (re-search-forward "\
+<span class=\"\\(.+audiolink.+\\|editsection\\)\".*>" nil t)
 	      (setq point (match-beginning 0))
 	      (goto-char point)
 	      (search-forward "</span>" nil t)
@@ -1269,7 +1294,7 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 	  (when aimai
 	    (insert (if (eq source 'ja.wikipedia)
 			"\n($B[#Kf$52sHr$N%Z!<%8(B)"
-		      "\n(Disambiguation)")))
+		      "\n(Disambiguation page)")))
 	  ;;
 	  (goto-char (point-max))
 	  (while (and (looking-at "^$")
@@ -1443,7 +1468,9 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 		(throw 'found (cons string cache-buffer))))))))))
 
 ;;;###autoload
-(defun skk-annotation-wikipedia-region (&optional prefix-arg start end)
+(defun skk-annotation-wikipedia-region-or-at-point (&optional prefix-arg start end)
+  "$BA*BrNN0h$^$?$O%]%$%s%H0LCV$NC18l$r(B Wikipedia/Wikitionary $B$GD4$Y$k!#(B
+$BNN0h$,A*Br$5$l$F$$$J$1$l$PC18l$N;O$a$H=*$o$j$r?dB,$7$FD4$Y$k!#(B"
   (interactive (cons (prefix-numeric-value current-prefix-arg)
 		     (cond
 		      ((static-if (featurep 'xemacs)
@@ -1479,6 +1506,10 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 		     (skk-annotation-wikipedia word sources)))
       (skk-annotation-show (or note "") word sources))))
 
+;;;###autoload
+(defalias 'skk-annotation-wikipedia-region
+  'skk-annotation-wikipedia-region-or-at-point)
+
 (defun skk-annotation-generate-url (format-string &rest args)
   (condition-case nil
       (require 'url-util)
@@ -1525,6 +1556,7 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
 	       (not (ignore-errors
 		      (require 'un-define)))))
       ;; Emacs 20.7 (MULE 4.0) $B$G$O%5%]!<%H$7$J$$(B
+      ;; Emacs 20.7 (MULE 4.1) $B$OGS=|$7$J$$$G$*$/(B
       (setq skk-annotation-url-package-available-p nil))
      (t
       ;; Emacs 21 $B$H(B XEmacs
@@ -1543,9 +1575,6 @@ Wikipedia\\(</a>\\)? has an article on:$" nil t)
   ;;
   skk-annotation-url-package-available-p)
 
-(require 'product)
-(product-provide
-    (provide 'skk-annotation)
-  (require 'skk-version))
+(provide 'skk-annotation)
 
 ;;; skk-annotation.el ends here
