@@ -6,9 +6,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-comp.el,v 1.79 2009/07/10 23:19:00 skk-cvs Exp $
+;; Version: $Id: skk-comp.el,v 1.81 2010/08/24 11:37:41 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2009/07/10 23:19:00 $
+;; Last Modified: $Date: 2010/08/24 11:37:41 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -38,7 +38,7 @@
   (require 'skk-vars)
 
   (defvar smart-find-file-path)
-
+  (defvar dont-bind-my-keys)
   (condition-case nil
       (let ((dont-bind-my-keys t))
 	(load "smart-find"))
@@ -567,9 +567,6 @@ WITHOUT-MIDASI $B$r;XDj$9$k$H8+=P$7$O>J$+$l$k!#(B"
 
 (run-hooks 'skk-comp-load-hook)
 
-(require 'product)
-(product-provide
-    (provide 'skk-comp)
-  (require 'skk-version))
+(provide 'skk-comp)
 
 ;;; skk-comp.el ends here
