@@ -33,7 +33,7 @@
   (require 'skk-macs))
 
 (require 'skk-vars)
-(require 'wid-edit)
+(require 'cus-edit)
 (require 'custom)
 
 (defvar skk-custom-params nil)
@@ -331,9 +331,6 @@
   ;;
   (setq skk-custom-alist nil))
 
-(require 'product)
-(product-provide
-    (provide 'skk-cus)
-  (require 'skk-version))
+(provide 'skk-cus)
 
 ;;; skk-cus.el ends here
