@@ -1,12 +1,14 @@
 ;;; skk-dcomp.el --- SKK dynamic completion -*- coding: iso-2022-jp -*-
 
 ;; Copyright (C) 1999, 2000, 2001 NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
+;; Copyright (C) 2008, 2009 IRIE Tetsuya <irie@t.email.ne.jp>
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
+;; Author: IRIE Tetsuya <irie@t.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-dcomp.el,v 1.63 2009/08/13 05:20:17 skk-cvs Exp $
+;; Version: $Id: skk-dcomp.el,v 1.66 2010/08/27 14:58:17 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2009/08/13 05:20:17 $
+;; Last Modified: $Date: 2010/08/27 14:58:17 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -110,7 +112,7 @@
 ;;; functions.
 ;; (defsubst skk-extentp (object)
 ;;   (static-cond
-;;    ((eq skk-emacs-type 'xemacs) (extentp object))
+;;    ((featurep 'xemacs) (extentp object))
 ;;    (t (overlayp object))))
 
 (defsubst skk-dcomp-face-on (start end)
@@ -207,7 +209,7 @@
 	 (goto-char (cdr pair))))))
 
 (defun skk-dcomp-multiple-available-p ()
-  (static-cond ((eq skk-emacs-type 'xemacs) nil)
+  (static-cond ((featurep 'xemacs) nil)
 	       ((< emacs-major-version 21) nil)
 	       (t (< (1+ skk-dcomp-multiple-rows)
 		     (skk-window-body-height)))))
@@ -674,9 +676,6 @@
     (when active
       (skk-dcomp-after-delete-backward-char))))
 
-(require 'product)
-(product-provide
-    (provide 'skk-dcomp)
-  (require 'skk-version))
+(provide 'skk-dcomp)
 
 ;;; skk-dcomp.el ends here
