@@ -1,6 +1,6 @@
 ;;; skk-e21.el --- GNU Emacs 21 support for SKK -*- coding: iso-2022-jp -*-
 
-;; Copyright (C) 1999-2007 SKK Development Team <skk@ring.gr.jp>
+;; Copyright (C) 1999-2010 SKK Development Team <skk@ring.gr.jp>
 
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
 ;; Keywords: japanese, mule, input method
@@ -94,11 +94,13 @@
     ("to Katakana, All Candidates" . "$B%+%?%+%J$KJQ49!"A4$F$N8uJd$rI=<((B")
     ("Hurigana" . "$B$U$j$,$J(B")
     ("Convert Region and Replace" . "$BNN0h$rJQ49$7$FCV$-49$($k(B")
-    ("Ascii" . "$BA43Q1Q?t$r(B ASCII $B$KJQ49(B")
     ("Hiragana" . "$B$R$i$,$J(B")
     ("Katakana" . "$B%+%?%+%J(B")
-    ("Romaji" . "$B%m!<%^;z$KJQ49(B")
-    ("Zenkaku" . "ASCII $B$rA43Q1Q?t$KJQ49(B")
+    ("Hiragana to Katakana" . "$B$R$i$,$J$r%+%?%+%J$KJQ49(B")
+    ("Katakana to Hiragana" . "$B%+%?%+%J$r$R$i$,$J$KJQ49(B")
+    ("Kana and Zenkaku to Romaji" . "$B$+$J!&%+%J!&A43Q$r%m!<%^;z$KJQ49(B")
+    ("Ascii to Zenkaku" . "ASCII $B$rA43Q1Q?t$KJQ49(B")
+    ("Zenkaku to Ascii" . "$BA43Q1Q?t$r(B ASCII $B$KJQ49(B")
     ("Count Jisyo Candidates" . "$B<-=qCf$N8uJd?t$r?t$($k(B")
     ("Save Jisyo" . "$B<-=q$rJ]B8$9$k(B")
     ("Undo Kakutei" . "$B3NDj$r<h$j>C$9(B ($B%"%s%I%%!<(B)")
@@ -145,12 +147,13 @@
   ;;
   (unless (or (null window-system)
 	      (eq window-system 'w32)
-	      (boundp 'mac-carbon-version-string)
+	      (boundp 'mac-carbon-version-string) ; Carbon Emacs
+	      (featurep 'ns) ; Cocoa Emacs
 	      (and (eq window-system 'x)
 		   (>= emacs-major-version 22)
 		   (boundp 'gtk-version-string)
 		   (stringp (symbol-value 'gtk-version-string))
-		   (string< "2.0" gtk-version-string)))
+		   (string< "2.0" (symbol-value 'gtk-version-string))))
     (setq skk-show-japanese-menu nil))
   ;;
   (when skk-show-japanese-menu
@@ -220,7 +223,7 @@
 
 (defun skk-e21-visit-openlab ()
   (interactive)
-  (browse-url "http://openlab.ring.gr.jp/skk/index-j.html"))
+  (browse-url "http://openlab.jp/skk/index-j.html"))
 
 ;;;###autoload
 (defun skk-e21-prepare-modeline-properties ()
@@ -580,15 +583,19 @@
 		  (skk-in-minibuffer-p))
 	  (message nil))
 	;;
-	(x-show-tip text (selected-frame) params skk-tooltip-hide-delay
-		    ;;
-		    (if (eq skk-tooltip-mouse-behavior 'follow)
-			skk-tooltip-x-offset
-		      tooltip-x-offset)
-		    ;;
-		    (if (eq skk-tooltip-mouse-behavior 'follow)
-			skk-tooltip-y-offset
-		      tooltip-y-offset)))
+	(let ((x-gtk-use-system-tooltips nil))
+	  ;; GTK $BIU(B Emacs $B$G!"(BGTK $B$N%D!<%k%F%#%C%W$rMxMQ$9$k$H(B
+	  ;; $B8=>u%U%'%$%9B0@-$,E,MQ$5$l$J$$$N$G!"(BEmacs $B$N%D!<%k(B
+	  ;; $B%F%#%C%W$rMQ$$$k!#(B
+	  (x-show-tip text (selected-frame) params skk-tooltip-hide-delay
+		      ;;
+		      (if (eq skk-tooltip-mouse-behavior 'follow)
+			  skk-tooltip-x-offset
+			tooltip-x-offset)
+		      ;;
+		      (if (eq skk-tooltip-mouse-behavior 'follow)
+			  skk-tooltip-y-offset
+			tooltip-y-offset))))
     (error
      (message "Error while displaying tooltip: %s" error)
      (sit-for 1)
@@ -601,9 +608,6 @@
 (defadvice tooltip-hide (after ccc-ad activate)
   (update-buffer-local-frame-params))
 
-(require 'product)
-(product-provide
-    (provide 'skk-e21)
-  (require 'skk-version))
+(provide 'skk-e21)
 
 ;;; skk-e21.el ends here
