@@ -1,6 +1,6 @@
 ;;; skk-jisyo-edit-mode.el --- major mode for editing SKK dictionaries -*- coding: euc-jp -*-
 
-;; Copyright (C) 2001-2007 SKK Development Team
+;; Copyright (C) 2001-2010 SKK Development Team
 
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
 ;; Keywords: japanese, mule, input method
@@ -85,7 +85,8 @@
   (run-hooks 'skk-jisyo-edit-mode-hook))
 
 ;;;###autoload
-(add-to-list 'auto-mode-alist '("SKK-JISYO" . skk-jisyo-edit-mode) t)
+(when (eval-when-compile (>= emacs-major-version 21))
+  (add-to-list 'auto-mode-alist '("SKK-JISYO" . skk-jisyo-edit-mode) t))
 ;;;###autoload
 (add-to-list 'auto-mode-alist '("\\.skk-jisyo\\(\\.BAK\\|\\.bak\\|~\\)?$"
 				. skk-jisyo-edit-mode))
@@ -174,9 +175,6 @@
 		     "You are editing private jisyo.  Can't purge."))
     ad-do-it))
 
-(require 'product)
-(product-provide
-    (provide 'skk-jisyo-edit)
-  (require 'skk-version))
+(provide 'skk-jisyo-edit)
 
 ;;; skk-jisyo-edit.el ends here
