@@ -3,12 +3,13 @@
 ;; Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997,
 ;;               1998, 1999, 2000
 ;;   Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
+;; Copyright (C) 1998-2010 SKK Development Team <skk@ring.gr.jp>
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-kcode.el,v 1.38 2009/11/02 03:56:13 skk-cvs Exp $
+;; Version: $Id: skk-kcode.el,v 1.47 2010/08/29 06:17:17 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2009/11/02 03:56:13 $
+;; Last Modified: $Date: 2010/08/29 06:17:17 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -38,6 +39,8 @@
   (defvar enable-recursive-minibuffers)
   (defvar message-log-max))
 
+(require 'skk-tankan)
+
 ;;;###autoload
 (defun skk-input-by-code-or-menu (&optional arg)
   "7bit $B$b$7$/$O(B 8bit $B$b$7$/$O(B $B6hE@%3!<%I$KBP1~$9$k(B 2byte $BJ8;z$rA^F~$9$k!#(B"
@@ -116,7 +119,7 @@
 ;; tiny function, but called once in skk-kcode.el.  So not make it inline.
 (defun skk-make-char (charset n1 n2)
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (make-char charset
 	       (logand (lognot 128) n1)
 	       (logand (lognot 128) n2)))
@@ -183,7 +186,8 @@
 	       str)
 	   (while (< i 12)
 	     (setq str (concat str
-			       (nth i menu-keys1)
+			       (propertize (nth i menu-keys1) 'face
+					   'skk-henkan-show-candidates-keys-face)
 			       ":"
 			       (car (nth i chars))
 			       "  "))
@@ -273,7 +277,8 @@
 	 (let ((i 0) message-log-max str)
 	   (while (< i 16)
 	     (setq str (concat str
-			       (nth i menu-keys2)
+			       (propertize (nth i menu-keys2) 'face
+					   'skk-henkan-show-candidates-keys-face)
 			       ":"
 			       (nth i chars)
 			       " "))
@@ -368,7 +373,11 @@
 
 (defun skk-display-code (str)
   (let* ((char (string-to-char str))
-	 (charset (char-charset char)))
+	 (charset (static-if (and (not (featurep 'xemacs))
+				  (>= emacs-major-version 23))
+		      ;; GNU Emacs 23.1 or later
+		      (char-charset char skk-charset-list)
+		    (char-charset char))))
     (cond
      ((memq charset '(japanese-jisx0213-1 japanese-jisx0213-2 japanese-jisx0208 japanese-jisx0208-1978))
       (let* ((char1-j (skk-char-octet char 0))
@@ -381,7 +390,11 @@
 		       (skk-jis2sjis2 char1-j char2-j)
 		     (skk-jis2sjis char1-j char2-j)))
 	     (char1-s (car sjis))
-	     (char2-s (cadr sjis)))
+	     (char2-s (cadr sjis))
+	     (list (skk-tankan-get-char-data char))
+	     (stroke (nth 2 list))
+	     (anno (skk-tankan-get-char-annotation char))
+	     )
 	(if (eq charset 'japanese-jisx0213-2)
 	    (message
 	     "`%s' (plane 2) KUTEN: %02d-%02d, JIS: %2x%2x, EUC: %2x%2x, SJIS: %2x%2x"
@@ -390,18 +403,31 @@
 	     char1-j char2-j
 	     char1-e char2-e
 	     char1-s char2-s)
+	  ;; 
 	  (message
-	   "`%s' KUTEN: %02d-%02d, JIS: %2x%2x, EUC: %2x%2x, SJIS: %2x%2x"
+	   "`%s' KUTEN: %02d-%02d, JIS: %2x%2x, EUC: %2x%2x, SJIS: %2x%2x%s%s"
 	   str
 	   char1-k char2-k
 	   char1-j char2-j 
 	   char1-e char2-e 
-	   char1-s char2-s))))
+	   char1-s char2-s
+	   (if (= 0 stroke)
+	       ""
+	     (format ", $BAm(B%d$B2h(B(%s$BIt(B%d$B2h(B)"
+		     stroke
+		     (aref skk-tankan-radical-vector (nth 0 list))
+		     (nth 1 list)))
+	   (if anno
+	       (concat ", " anno)
+	     "")
+	   ))))
+     ;;
      ((memq charset '(ascii latin-jisx0201))
       (message "`%s' HEX: %2x, DECIMAL: %3d"
 	       str
 	       (skk-char-octet char 0)
 	       (skk-char-octet char 0)))
+     ;;
      (t
       (skk-error "$BH=JL$G$-$J$$J8;z$G$9(B"
 		 "Cannot understand this character")))))
@@ -425,22 +451,13 @@
     (list c1 c2)))
 
 ;; 2$BLL(B
-(defun skk-jis2sjis2 (char1 char2)
-  (let* ((ch2 (if (eq (* (/ char1 2) 2) char1)
-		  (+ char2 125) (+ char2 31)))
-	 (c2 (if (>= ch2 127)
-		 (+ ch2 1) ch2))
-         (ku (- char1 32))
-         (c1 (if (<= ku 15)
-		 (- (/ (+ ku ?\x1df) 2) (* (/ ku 8) 3))
-	       (/ (+ ku ?\x19b) 2))))
-    (list c1 c2)))
+;; XEmacs $B$G$N%(%i!<2sHr$N$?$a$K$3$N4X?t$r0l;~(B skk-emacs.el $B$KB`Hr$9$k!#(B
+;; (autoload 'skk-jis2sjis2 "skk-emacs")
+(static-when (featurep 'xemacs)
+  (defalias 'skk-jis2sjis2 'ignore))
 
 (run-hooks 'skk-kcode-load-hook)
 
-(require 'product)
-(product-provide
-    (provide 'skk-kcode)
-  (require 'skk-version))
+(provide 'skk-kcode)
 
 ;;; skk-kcode.el ends here
