@@ -1,13 +1,13 @@
 ;;; skk-macs.el --- macros and inline functions commonly used in SKK -*- coding: iso-2022-jp -*-
 
-;; Copyright (C) 1999-2008  SKK Development Team <skk@ring.gr.jp>
+;; Copyright (C) 1999-2010  SKK Development Team <skk@ring.gr.jp>
 ;; Copyright (C) 1993, 2000 Free Software Foundation, Inc.
 
 ;; Author: SKK Development Team <skk@ring.gr.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-macs.el,v 1.136 2009/11/02 03:56:13 skk-cvs Exp $
+;; Version: $Id: skk-macs.el,v 1.145 2010/09/03 20:40:45 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2009/11/02 03:56:13 $
+;; Last Modified: $Date: 2010/09/03 20:40:45 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -43,7 +43,7 @@
 
 ;;;; macros
 
-(put 'ignore-errors 'defmacro-maybe (not (eq skk-emacs-type 'xemacs)))
+(put 'ignore-errors 'defmacro-maybe (not (featurep 'xemacs)))
 (defmacro-maybe ignore-errors (&rest body)
   "Execute FORMS; if an error occurs, return nil.
 Otherwise, return result of last FORM."
@@ -153,7 +153,7 @@ doesn't give arguments of `interactive'. See `interactive' for details."
 
 (defmacro skk-message (japanese english &rest arg)
   "$B%a%C%;!<%8$rI=<($9$k!#(B
-`skk-japanese-message-and-error' $B$,(B non-nil $B$@$C$?$i(B JAPANESE $B$r(B nil $B$G$"$l$P(B
+`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l$P(B
 ENGLISH $B$r%(%3!<%(%j%"$KI=<($9$k!#(BARG $B$O(B `message' $B4X?t$NBh#20z?t0J9_$N0z?t$H(B
 $B$7$FEO$5$l$k!#(B"
   (append
@@ -170,7 +170,7 @@ ENGLISH $B$r%(%3!<%(%j%"$KI=<($9$k!#(BARG $B$O(B `message' $B4X?t$NBh#20z?t
 
 (defmacro skk-error (japanese english &rest arg)
   "$B%a%C%;!<%8$rI=<($7$F!"%(%i!<$rH/@8$5$;$k!#(B
-`skk-japanese-message-and-error' $B$,(B non-nil $B$@$C$?$i(B JAPANESE $B$r(B nil $B$G$"$l$P(B
+`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l$P(B
 ENGLISH $B$r%(%3!<%(%j%"$KI=<($7!"%(%i!<$rH/@8$5$;$k!#(B ARG $B$O(B `error' $B4X?t$NBh(B
 $B#20z?t0J9_$N0z?t$H$7$FEO$5$l$k!#(B"
   (append
@@ -186,8 +186,8 @@ ENGLISH $B$r%(%3!<%(%j%"$KI=<($7!"%(%i!<$rH/@8$5$;$k!#(B ARG $B$O(B `error'
    arg))
 
 (defmacro skk-yes-or-no-p (japanese english)
-  "$B%f!<%6$K(B yes-or-no $B$N<ALd$r$7!"Ez$($,(B yes $B$@$C$?$i(B t $B$rJV$9!#(B
-`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r(B nil $B$G$"$l(B
+  "$B%f!<%6$K(B yes-or-no $B$r<ALd$7!"Ez$($,(B yes $B$@$C$?$i(B t $B$rJV$9!#(B
+`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l(B
 $B$P(B ENGLISH $B$r%W%m%s%W%H$H$7$F(B `yes-or-no-p' $B$r<B9T$9$k!#(B
 `yes-or-no-p' $B$N0z?t$N%W%m%s%W%H$,J#;($KF~$l9~$s$G$$$k>l9g$O$3$N%^%/%m$r;H$&(B
 $B$h$j%*%j%8%J%k$N(B `yes-or-no-p' $B$r;HMQ$7$?J}$,%3!<%I$,J#;($K$J$i$J$$>l9g$,$"(B
@@ -196,8 +196,8 @@ ENGLISH $B$r%(%3!<%(%j%"$KI=<($7!"%(%i!<$rH/@8$5$;$k!#(B ARG $B$O(B `error'
 				   japanese english)))
 
 (defmacro skk-y-or-n-p (japanese english)
-  "$B%f!<%6$K(B \"y or n\" $B$N<ALd$r$7!"Ez$($,(B \"y\" $B$@$C$?$i(B t $B$rJV$9!#(B
-`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r(B nil $B$G$"$l(B
+  "$B%f!<%6$K(B \"y or n\" $B$r<ALd$7!"Ez$($,(B \"y\" $B$@$C$?$i(B t $B$rJV$9!#(B
+`skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l(B
 $B$P(B ENGLISH $B$r%W%m%s%W%H$H$7$F(B `y-or-n-p' $B$r<B9T$9$k!#(B"
   (list 'y-or-n-p (list 'if 'skk-japanese-message-and-error
 				japanese english)))
@@ -222,7 +222,7 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
 
 (defmacro skk-face-on (object start end face &optional priority)
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     `(let ((inhibit-quit t))
        (if (not (extentp ,object))
 	   (progn
@@ -368,7 +368,7 @@ the echo area while this function is waiting for an event."
 (defsubst skk-sit-for (seconds &optional nodisplay)
   "`sit-for' $B$N(B Emacsen $B$K$h$k0c$$$r5[<}$9$k!#(B"
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (sit-for seconds nodisplay))
    ((< emacs-major-version 22)
     (sit-for seconds nil nodisplay))
@@ -378,14 +378,14 @@ the echo area while this function is waiting for an event."
 (defsubst skk-ding (&optional arg sound device)
   "`ding' $B$N(B Emacsen $B$K$h$k0c$$$r5[<}$9$k!#(B"
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
      (ding arg sound device))
    (t
     (ding arg))))
 
-(defsubst skk-color-display-p ()
+(defsubst skk-color-cursor-display-p ()
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (eq (device-class (selected-device)) 'color))
    ((fboundp 'x-display-color-p)
     ;; FSF Emacs on X Window System.
@@ -394,28 +394,32 @@ the echo area while this function is waiting for an event."
 (defsubst skk-char-to-unibyte-string (char)
   (ignore-errors
     (static-cond
-     ((memq skk-emacs-type '(mule6))
+     ((and (string-match "^GNU" (emacs-version))
+	   (>= emacs-major-version 23))
       (string-make-unibyte (char-to-string char)))
      (t
       (char-to-string char)))))
 
 (defsubst skk-ascii-char-p (char)
   (static-cond
-   ((memq skk-emacs-type '(mule6))
+   ((and (string-match "^GNU" (emacs-version))
+	 (>= emacs-major-version 23))
     (eq (char-charset char skk-charset-list) 'ascii))
    (t
     (eq (char-charset char) 'ascii))))
 
 (defsubst skk-jisx0208-p (char)
   (static-cond
-   ((memq skk-emacs-type '(mule6))
+   ((and (string-match "^GNU" (emacs-version))
+	 (>= emacs-major-version 23))
     (eq (char-charset char skk-charset-list) 'japanese-jisx0208))
    (t
     (eq (char-charset char) 'japanese-jisx0208))))
 
 (defsubst skk-jisx0213-p (char)
   (static-cond
-   ((memq skk-emacs-type '(mule6))
+   ((and (string-match "^GNU" (emacs-version))
+	   (>= emacs-major-version 23))
        (memq (char-charset char skk-charset-list)
 	     '(japanese-jisx0213.2004-1
 	       japanese-jisx0213-1
@@ -434,7 +438,8 @@ the echo area while this function is waiting for an event."
 
 (defun skk-split-char (ch)
   (static-cond
-   ((memq skk-emacs-type '(mule6))
+   ((and (string-match "^GNU" (emacs-version))
+	 (>= emacs-major-version 23))
     ;; C $B$N(B split-char $B$HF1MM$N5!G=$@$,!"(Bchar-charset $B$N8F=P$7$K$*$$$F(B
     ;; $BJ8;z=89g$NA*Br;h$r(B skk-charset-list $B$K4^$^$l$k$b$N$K@)8B$9$k!#(B
     ;; $B$3$l$ONc$($P!"(Bjapanese-jisx0208 $B$NJ8;z$,(B unicode-bmp $B$KB0$9$k!"(B
@@ -456,7 +461,7 @@ the echo area while this function is waiting for an event."
 ;; this one is called once in skk-kcode.el, too.
 (defsubst skk-charsetp (object)
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (find-charset object))
    (t
     ;; FSF Emacs 20 or later.
@@ -465,11 +470,11 @@ the echo area while this function is waiting for an event."
 (defun skk-indicator-to-string (indicator &optional no-properties)
   "SKK $B%$%s%8%1!<%?7?%*%V%8%'%/%H(B INDICATOR $B$rJ8;zNs$KJQ49$9$k!#(B"
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (if (stringp indicator)
 	indicator
       (cdr indicator)))
-   ((memq skk-emacs-type '(mule5 mule6))
+   ((>= emacs-major-version 21)
     (if no-properties
 	(with-temp-buffer
 	  (insert indicator)
@@ -481,10 +486,10 @@ the echo area while this function is waiting for an event."
 (defun skk-mode-string-to-indicator (mode string)
   "$BJ8;zNs(B STRING $B$r(B SKK $B%$%s%8%1!<%?7?%*%V%8%'%/%H$KJQ49$9$k!#(B"
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (cons (cdr (assq mode skk-xemacs-extent-alist))
 	  string))
-   ((memq skk-emacs-type '(mule5 mule6))
+   ((>= emacs-major-version 21)
     (if (and window-system
 	     (not (eq mode 'default)))
 	(apply 'propertize string
@@ -497,23 +502,23 @@ the echo area while this function is waiting for an event."
   "Non-nil if VARIABLE has a local binding in buffer BUFFER.
 BUFFER defaults to the current buffer."
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (local-variable-p variable (or buffer (current-buffer)) afterset))
    (t
     (local-variable-p variable (or buffer (current-buffer))))))
 
 (defsubst skk-face-proportional-p (face)
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (face-proportional-p face))
-   ((memq skk-emacs-type '(mule5 mule6))
+   ((>= emacs-major-version 21)
     (or (face-equal face 'variable-pitch)
 	(eq (face-attribute face :inherit) 'variable-pitch)))))
 
 (defun skk-event-key (event)
   "$B%$%Y%s%H(B EVENT $B$rH/@8$7$?F~NO$N>pJs$r<hF@$9$k!#(B"
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
 ;    (let ((tmp (event-key event)))
 ;      (if (symbolp tmp)
 ;	  (vector tmp)
@@ -537,14 +542,14 @@ BUFFER defaults to the current buffer."
 ;; last-command-char is a character equivalent to last-command-event.
 (defsubst skk-last-command-char ()
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     last-command-char)
    (t
     last-command-event)))
 
 (defsubst skk-set-last-command-char (char)
   (let ((variable (static-cond
-		   ((eq skk-emacs-type 'xemacs)
+		   ((featurep 'xemacs)
 		    'last-command-char)
 		   (t
 		    'last-command-event))))
@@ -552,7 +557,7 @@ BUFFER defaults to the current buffer."
 
 (put 'skk-bind-last-command-char 'lisp-indent-function 1)
 (defmacro skk-bind-last-command-char (char &rest body)
-  (let ((variable (cond ((eq skk-emacs-type 'xemacs)
+  (let ((variable (cond ((featurep 'xemacs)
 			 'last-command-char)
 			(t
 			 'last-command-event))))
@@ -562,11 +567,15 @@ BUFFER defaults to the current buffer."
 
 ;;; version independent
 (defsubst skk-cursor-set (&optional color force)
+  (unless (skk-color-cursor-display-p)
+    (setq skk-use-color-cursor nil))
   (when (or skk-use-color-cursor
 	    force)
     (skk-cursor-set-1 color)))
 
 (defsubst skk-cursor-off ()
+  (unless (skk-color-cursor-display-p)
+    (setq skk-use-color-cursor nil))
   (when skk-use-color-cursor
     (skk-cursor-off-1)))
 
@@ -641,7 +650,7 @@ BUFFER defaults to the current buffer."
   (assq char (skk-get-branch-list tree)))
 
 (defun skk-erase-prefix (&optional clean)
-  "`skk-echo' $B$,Hs(B nil $B$G$"$l$P8=:_I=<($5$l$F$$$k(B `skk-prefix' $B$r>C$9!#(B
+  "`skk-echo' $B$,(B non-nil $B$G$"$l$P8=:_I=<($5$l$F$$$k(B `skk-prefix' $B$r>C$9!#(B
 $B%*%W%7%g%s0z?t$N(B CLEAN $B$,;XDj$5$l$k$H!"JQ?t$H$7$F$N(B `skk-prefix' $B$r6uJ8;z$K!"(B
 `skk-current-rule-tree' $B$r(B nil $B$K=i4|2=$9$k!#(B"
   ;; $B$+$JJ8;z$NF~NO$,$^$@40@.$7$F$$$J$$>l9g$K$3$N4X?t$,8F$P$l$?$H$-$J$I$O(B
@@ -792,13 +801,18 @@ BUFFER defaults to the current buffer."
 		    (t (if header-line-format 1 0))))))
 
 (defun skk-screen-column ()
+  "$B%9%/%j!<%s9T$+$iF@$?%+!<%=%k0LCV$N7e?t$rJV$9!#(B
+$B%F%-%9%H9T!J2~9TJ8;z$G6h@Z$i$l$?%F%-%9%H!K$,%&%#%s%I%&I}$r1[$($F@^$jJV$7$FI=<($5$l$F$$$k>l9g$K$bBP1~$9$k!#(B"
   (- (current-column)
      (save-excursion
-       (vertical-motion 0)
-       (current-column))))
+       (vertical-motion 0)		;$B%9%/%j!<%s9T$N9TF,$K0\F0$9$k(B
+       (current-column))))		;$B",$3$N7k2L!"%9%/%j!<%s9T$N9TF,$J$N$+(B
+					;$B%F%-%9%H9T$N9TF,$J$N$+(B
 
 (defun skk-move-to-screen-column (col)
-  (move-to-column (+ (current-column)
+  "$B%9%/%j!<%s9T$+$i8+$?(B COL $B7e0LCV$K%]%$%s%H$r0\F0$9$k!#(B
+$B%F%-%9%H9T!J2~9TJ8;z$G6h@Z$i$l$?%F%-%9%H!K$,%&%#%s%I%&I}$r1[$($F@^$jJV$7$FI=<($5$l$F$$$k>l9g$K$bBP1~$9$k$,!"2~9TJ8;z$r1[$($k0\F0$O9T$o$J$$!#(B"
+  (move-to-column (+ (current-column)	;$B%F%-%9%H9T$+$i8+$?7e?t(B
 		     (- col (skk-screen-column))))
   (skk-screen-column))
 
@@ -963,7 +977,7 @@ BUFFER defaults to the current buffer."
    (append word nil) ""))
 
 (defun skk-key-binding-member (key commands &optional map)
-  "$BF~NO(B KEY $B$,H/F0$9$k%3%^%s%I$,!"(BCOMMANDS $B$K4^$^$l$l$P(B $BHs(B nil $B$rJV$9!#(B
+  "$BF~NO(B KEY $B$,H/F0$9$k%3%^%s%I$,!"(BCOMMANDS $B$K4^$^$l$l$P(B non-nil $B$rJV$9!#(B
 MAP $B$OF~NO$,=q$+$l$F$$$k%-!<%^%C%W$r;XDj$9$k$,!";XDj$5$l$J$1$l$P(B
 `skk-j-mode-map' $B$r;2>H$9$k!#(B
 $B$3$N4X?t$O!"F~NO(B KEY $B$,(B `lookup-key' $B$GC5$;$J$$7A<0$G$"$j$&$k>l9g$KMQ$$$k!#(B"
@@ -978,9 +992,6 @@ MAP $B$OF~NO$,=q$+$l$F$$$k%-!<%^%C%W$r;XDj$9$k$,!";XDj$5$l$J$1$l$P(B
 			(key-description k))
 		    keys))))
 
-(require 'product)
-(product-provide
-    (provide 'skk-macs)
-  (require 'skk-version))
+(provide 'skk-macs)
 
 ;;; skk-macs.el ends here
