@@ -4,9 +4,9 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-obsolete.el,v 1.18 2007/09/08 01:12:34 skk-cvs Exp $
+;; Version: $Id: skk-obsolete.el,v 1.21 2010/08/19 13:53:14 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2007/09/08 01:12:34 $
+;; Last Modified: $Date: 2010/08/19 13:53:14 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -94,7 +94,7 @@
     (skk-zenkaku-mode-map . skk-jisx0208-latin-mode-map)
     (skk-zenkaku-mode-string . skk-jisx0208-latin-mode-string)
     (skk-zenkaku-vector . skk-jisx0208-latin-vector))
-  "obsolete $BJQ?t$N%(!<%j%9%H!#(B")
+  "obsolete $BJQ?t$NO"A[%j%9%H!#(B")
 
 (defvar skk-obsolete-function-alist
   '((skk-adjust-numeric-henkan-data . skk-num-process-user-minibuf-input)
@@ -139,11 +139,11 @@
     (skk-zenkaku-mode-on . skk-jisx0208-latin-mode-on)
     (skktut-quit-tutorial . skk-tutorial-quit)
     (skktut-tutorial-again . skk-tutorial-again))
-  "obsolete $B4X?t$N%(!<%j%9%H!#(B")
+  "obsolete $B4X?t$NO"A[%j%9%H!#(B")
 
 ;;;###autoload
 (defun skk-obsolete-check (file)
-  "FILE $BFb$N(B obsolete $BJQ?tL>$H(B obsolete $B4X?tL>$r%A%'%C%/$7!"=q49$($k!#(B"
+  "FILE $BFb$N(B obsolete $BJQ?tL>$H(B obsolete $B4X?tL>$r%A%'%C%/$7!"=q$-49$($k!#(B"
   (interactive
    (list (read-file-name
 	  (format "File to check: (default: %s) "
@@ -154,9 +154,8 @@
 
 ;;;###autoload
 (defun skk-obsolete-check-all-files (&optional program-files-too)
-  "$B4XO"%U%!%$%kA4$F$N(B obsolete $BJQ?tL>$H(B obsolete $B4X?tL>$r%A%'%C%/$7!"=q49$($k!#(B
-C-u M-x skk-obsolete-check-all-files $B$N$h$&$K5/F0$7$?$H$-$O!"%G%#%U%)%k%H%G%#%l(B
-$B%/%H%j$K$"$k(B SKK $B%W%m%0%i%`%U%!%$%k$b%A%'%C%/$r9T$J$&!#(B"
+  "$B4XO"%U%!%$%kA4$F$N(B obsolete $BJQ?tL>$H(B obsolete $B4X?tL>$r%A%'%C%/$7!"=q$-49$($k!#(B
+C-u M-x skk-obsolete-check-all-files $B$H%W%l%U%#%C%/%9IU$-$G5/F0$7$?$H$-$O!"%G%U%)%k%H%G%#%l%/%H%j$K$"$k(B SKK $B%W%m%0%i%`%U%!%$%k$b%A%'%C%/$r9T$J$&!#(B"
   (interactive "p")
   (save-window-excursion
     (let ((lp load-path)
@@ -255,7 +254,9 @@ It is strongly recommended to kill and restart Emacs.  Kill Emacs?"))
 	;;(fl skk-obsolete-function-alist))
 	)
     (while vl
-      (make-obsolete-variable (car (car vl)) (cdr (car vl)))
+      (if (eval-when-compile (< emacs-major-version 21))
+	  (make-obsolete-variable (car (car vl)) (cdr (car vl)))
+	(make-obsolete-variable (car (car vl)) (cdr (car vl)) nil))
       (setq vl (cdr vl)))
     ;; Put mark by define-obsolete-function-alias in skk-foreword.el.
     ;;(while fl
@@ -263,9 +264,6 @@ It is strongly recommended to kill and restart Emacs.  Kill Emacs?"))
     ;;  (setq fl (cdr fl)))))
    ))
 
-(require 'product)
-(product-provide
-    (provide 'skk-obsolete)
-  (require 'skk-version))
+(provide 'skk-obsolete)
 
 ;;; skk-obsolete.el ends here
