@@ -1,4 +1,4 @@
-;;; skk-server.el --- SKK $B%5!<%P!<$N$?$a$N%W%m%0%i%`(B -*- coding: iso-2022-jp -*-
+;;; skk-server.el --- $B<-=q%5!<%P!<$N$?$a$N%W%m%0%i%`(B -*- coding: iso-2022-jp -*-
 
 ;; Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996,
 ;;               1997, 1998, 1999, 2000, 2001
@@ -6,9 +6,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-server.el,v 1.43 2007/09/06 13:50:22 skk-cvs Exp $
+;; Version: $Id: skk-server.el,v 1.46 2010/08/24 22:10:56 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2007/09/06 13:50:22 $
+;; Last Modified: $Date: 2010/08/24 22:10:56 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -55,13 +55,13 @@ When called interactively, print version information."
    ((not (or skk-server-host
 	     skk-servers-list))
     (skk-error "Lack of host information of SKK server"
-	       "SKK $B%5!<%P!<$N%[%9%H>pJs$,$"$j$^$;$s(B"))
+	       "$B<-=q%5!<%P!<$N%[%9%H>pJs$,$"$j$^$;$s(B"))
    ((skk-server-live-p (skk-open-server))
     (let (v)
       (save-match-data
 	(with-current-buffer skkserv-working-buffer
 	  (erase-buffer)
-	  ;; $B%5!<%P!<%P!<%8%g%s$rF@$k!#(B
+	  ;; $B<-=q%5!<%P!<$N%P!<%8%g%s$rF@$k!#(B
 	  (process-send-string skkserv-process "2")
 	  (while (eq (buffer-size) 0)
 	    (accept-process-output))
@@ -102,7 +102,7 @@ When called interactively, print version information."
 	  (while (and cont (skk-server-live-p))
 	    (accept-process-output)
 	    ;; XXX workaround
-	    ;; dbskkd-cdb $B$d(B skksearch $B$J$I$N(B SKK $B%5!<%P!<$r;H$C$FJQ49$9$k(B
+	    ;; dbskkd-cdb $B$d(B skksearch $B$J$I$N<-=q%5!<%P!<$r;H$C$FJQ49$9$k(B
 	    ;; $B:]$K!"(B2 $BIC$[$IBT$?$5$l$k$3$H$,$"$k!#$I$&$d$i1~EzBT$A$N%k!<%W(B
 	    ;; $B$,IiC4$K$J$C$F$$$k$h$&$G!"B?$$$H$-$K$O?tI4!A:GBg$G?t==K|2s$N(B
 	    ;; $B1~EzBT$A$K$J$k$3$H$,$"$k!#(Bskk-server-report-response $B$r(B t $B$K(B
@@ -122,7 +122,7 @@ When called interactively, print version information."
 		(setq cont nil))))
 	  (goto-char (point-min))
 	  (when skk-server-report-response
-	    (skk-message "%d $B2s(B SKK $B%5!<%P!<$N1~EzBT$A$r$7$^$7$?(B"
+	    (skk-message "$B<-=q%5!<%P!<$N1~Ez$r(B %d $B2sBT$A$^$7$?(B"
 			 "Waited for server response %d times"
 			 count))
 	  (when (eq (following-char) ?1) ;?1
@@ -140,10 +140,12 @@ When called interactively, print version information."
 		     (car l))))))))
      (t
       ;; server is not active, so search file instead
-      (skk-search-jisyo-file file limit)))))
+      (when (and (stringp file)
+		 (file-readable-p file))
+	(skk-search-jisyo-file file limit))))))
 
 (defun skk-open-server ()
-  "SKK $B%5!<%P!<$H@\B3$9$k!#%5!<%P!<%W%m%;%9$rJV$9!#(B"
+  "$B<-=q%5!<%P!<$H@\B3$9$k!#%5!<%P!<%W%m%;%9$rJV$9!#(B"
   (unless (skk-server-live-p)
     (setq skkserv-process (skk-open-server-1))
     (when (skk-server-live-p)
@@ -240,7 +242,7 @@ HOST $B$,(B nil $B$J$i$P(B `skk-server-host' $B$r;2>H$9$k!#(B
       ;; skkserv $B$N5/F0%H%i%$%"%k$r7+$jJV$9(B...?
       (while (> count 0)
 	(skk-message
-	 "%s $B$N(B SKK $B%5!<%P!<$,5/F0$7$F$$$^$;$s!#5/F0$7$^$9(B%s"
+	 "%s $B$N<-=q%5!<%P!<$,5/F0$7$F$$$^$;$s!#5/F0$7$^$9(B%s"
 	 "SKK SERVER on %s is not active, I will activate it%s"
 	 host (make-string count ?.))
 	(if (or (string= host (system-name))
@@ -265,14 +267,14 @@ HOST $B$,(B nil $B$J$i$P(B `skk-server-host' $B$r;2>H$9$k!#(B
       ;;
       (cond
        ((skk-server-live-p process)
-	(skk-message "$B%[%9%H(B %s $B$N(B SKK $B%5!<%P!<$,5/F0$7$^$7$?(B"
+	(skk-message "$B%[%9%H(B %s $B$N<-=q%5!<%P!<$,5/F0$7$^$7$?(B"
 		     "SKK SERVER on %s is active now"
 		     skk-server-host)
 	(sit-for 1)
 	;; process $B$rJV$jCM$H$9$k(B
 	process)
        (t
-	(skk-message "%s $B$N(B SKK $B%5!<%P!<$r5/F0$9$k$3$H$,$G$-$^$;$s$G$7$?(B"
+	(skk-message "%s $B$N<-=q%5!<%P!<$r5/F0$9$k$3$H$,$G$-$^$;$s$G$7$?(B"
 		     "Could not activate SKK SERVER on %s"
 		     skk-server-host)
 	(sit-for 1)
@@ -302,7 +304,7 @@ non-nil $B$G$"$l$P!"2C$($k!#(B"
 
 ;;;###autoload
 (defun skk-disconnect-server ()
-  "$B%5!<%P!<$r@Z$jN%$9!#(B"
+  "$B<-=q%5!<%P!<$r@Z$jN%$9!#(B"
   (when (and skk-server-host
 	     (skk-server-live-p))
     ;; disconnect server
@@ -319,9 +321,6 @@ non-nil $B$G$"$l$P!"2C$($k!#(B"
 
 (run-hooks 'skk-server-load-hook)
 
-(require 'product)
-(product-provide
-    (provide 'skk-server)
-  (require 'skk-version))
+(provide 'skk-server)
 
 ;;; skk-server.el ends here
