@@ -3,10 +3,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@namazu.org>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-study.el,v 1.53 2007/04/22 02:38:26 skk-cvs Exp $
+;; Version: $Id: skk-study.el,v 1.55 2010/08/24 11:37:41 skk-cvs Exp $
 ;; Keywords: japanese
 ;; Created: Apr. 11, 1999
-;; Last Modified: $Date: 2007/04/22 02:38:26 $
+;; Last Modified: $Date: 2010/08/24 11:37:41 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -75,7 +75,8 @@
 ;;; Code:
 
 (eval-when-compile
-  (require 'cl))
+  (require 'cl)
+  (defvar print-quoted))
 
 (require 'pym)
 (require 'skk-macs)
@@ -200,8 +201,6 @@
 $B%*%W%7%g%J%k0z?t$N(B NOMSG $B$,(B non-nil $B$G$"$l$P!"J]B8%a%C%;!<%8$r=PNO$7$J$$!#(B"
   (interactive "P")
   (let ((inhibit-quit t)
-	(last-time
-	 (nth 5 (file-attributes (expand-file-name skk-study-file))))
 	e)
     (if (or (and (null skk-study-alist) (not nomsg))
 	    (not skk-study-last-read)
@@ -398,6 +397,6 @@
 
 (add-hook 'kill-emacs-hook 'skk-study-save)
 
-(require 'product)
-(product-provide (provide 'skk-study) (require 'skk-version))
+(provide 'skk-study)
+
 ;;; skk-study.el ends here
