@@ -3,13 +3,13 @@
 ;; Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997,
 ;;               1998, 1999, 2000, 2001, 2002
 ;;   Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
-;; Copyright (C) 1999-2007  SKK Development Team <skk@ring.gr.jp>
+;; Copyright (C) 1999-2010  SKK Development Team <skk@ring.gr.jp>
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-tut.el,v 1.68 2010/01/30 03:44:19 skk-cvs Exp $
+;; Version: $Id: skk-tut.el,v 1.76 2010/08/27 10:42:18 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/01/30 03:44:19 $
+;; Last Modified: $Date: 2010/08/27 10:42:18 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -86,7 +86,7 @@
     (skk-date-ad . 1)
     (skk-cursor-default-color
      . (cond
-	((eq skk-emacs-type 'xemacs)
+	((featurep 'xemacs)
 	 (frame-property (selected-frame) 'cursor-color))
 	(t
 	 (cdr
@@ -102,7 +102,13 @@
     (skk-henkan-okuri-strictly . nil)
     (skk-henkan-overlay-priority . 600)
     (skk-henkan-show-candidates-keys . '(?a ?s ?d ?f ?j ?k ?l))
+    (skk-henkan-show-candidates-rows . 1)
+    (skk-show-candidates-always-pop-to-buffer . nil)
     (skk-henkan-strict-okuri-precedence . nil)
+    (skk-previous-candidate-char
+     . (if (equal skk-tut-file skktut-nicola-tut-file)
+	   ?\C-p
+	?x))
     (skk-hiragana-mode-string . " $B$+$J(B")
     (skk-init-file . "")
     (skk-input-by-code-menu-keys1 . '(?a ?s ?d ?f ?g ?h ?q ?w ?e ?r ?t ?y))
@@ -293,6 +299,7 @@
     (skk-use-viper . nil)
     (skk-show-tooltip . nil)
     (skk-show-inline . nil)
+    (skk-show-annotation . nil)
     (skk-kcode-charset . (if (featurep 'jisx0213)
 			     (quote japanese-jisx0208)
 			   skk-kcode-charset))
@@ -491,8 +498,6 @@ You can select English version by \\[universal-argument] \\[skk-tutorial]."
       (message "Language for the tutorial is %s until you exit Emacs"
 	       lang)))
   (let ((inhibit-quit t))
-    (unless (product-version>= 'skk-version '(11 3))
-      (error "%s" "Daredevil SKK or later is required"))
     (skktut-pre-setup-tutorial)
     (skktut-setup-jisyo-buffer)
     (skktut-setup-working-buffer)
@@ -601,9 +606,9 @@ You can select English version by \\[universal-argument] \\[skk-tutorial]."
   (delete-other-windows)
   (split-window-vertically)
   (let ((height (window-height (selected-window))))
-    (unless (< 19 height)
-      ;; Keep at least 20 lines for the upper window.
-      (enlarge-window (- 20 height))))
+    (unless (< 22 height)
+      ;; Keep at least 23 lines for the upper window.
+      (enlarge-window (- 23 height))))
   (other-window 1)
   ;; make it selected window and current buffer.
   (switch-to-buffer skktut-answer-buffer)
@@ -678,6 +683,7 @@ You can select English version by \\[universal-argument] \\[skk-tutorial]."
 
 (defun skktut-update-jisyo (word &optional purge)
   (let ((skk-share-private-jisyo nil)
+	(skk-jisyo-update-vector nil)
 	(skk-update-jisyo-count 0))
     (skk-update-jisyo-original word purge)))
 
@@ -854,12 +860,13 @@ tutorial /$B%A%e!<%H%j%"%k(B/
       (setq skktut-right-answer
 	    (buffer-substring-no-properties
 	     (+ 3 (point))
-	     (skk-save-point (end-of-line) (point)))))
+	     (skk-save-point (end-of-line) (point))))
+      (goto-char (point-min)))
     ;; not to save point.
     (let ((cbuf (current-buffer))
 	  p)
       (unwind-protect
-	  (let ((plist (cons (if (eq skk-emacs-type 'xemacs)
+	  (let ((plist (cons (if (featurep 'xemacs)
 				 'end-open
 			       'rear-nonsticky)
 			     '(t intangible t read-only t))))
@@ -965,9 +972,8 @@ SKK $B%A%e!<%H%j%"%k$O$3$l$G=*$j$G$9!#(B
 \t%s
 
 $BKx$*Aw$j2<$5$$!#$J$*!"$3$N%"%I%l%9$O(B SKK Ring Server Openlab Mailing
-List $B$N%"%I%l%9$G$9!#$I$J$?$G$bEj9F$O$G$-$^$9$,!"%a%s%P!<$K$7$+G[Aw$5$l(B
-$B$J$$$N$G!"%a%s%P!<$G$J$$J}$O$=$N;]$rL@5-$7$F%a!<%k$r$*Aw$j$/$@$5$$!#(B
-SKK Ring Server Openlab ML $B$X;22C4uK>$N>l9g$O(B
+List $B$N%"%I%l%9$G$9!#$?$@$78=:_!"Ej9F$G$-$k$N$O%a%s%P!<$K8B$i$l$^$9!#(B
+$BEj9FA0$K(B ML $B$K;22C$7$F$/$@$5$$!#(BML $B$K;22C$9$k$K$O(B
 
 \t%s
 
@@ -983,17 +989,15 @@ Please send comments, questions and bug reports on %s to:
 \t%s
 
 This is the address of the SKK Ring Server Openlab Mailing list.
-Anyone can post, but responces will be sent only to the ML members.
-So, if you are not a ML member, please say so in your mail.
-If you are interested in joining the SKK Ring Server Openlab ML,
-send mail to:
+Note that only members can post to the ML.  So, if you are not an
+ML member, please subscribe to the ML first, by sending email to:
 
 \t%s
 
-with empty body and subject.
+with both the subject and the body empty.
 
 !! Hit <return> key when you are ready.")
-		 (product-string-1 'skk-version t)
+		 (skk-version t)
 		 skk-ml-address
 		 skk-ml-command-address))
     (when skk-tut-use-face
@@ -1049,9 +1053,6 @@ with empty body and subject.
 	  name
 	"nanasi"))))
 
-(require 'product)
-(product-provide
-    (provide 'skk-tut)
-  (require 'skk-version))
+(provide 'skk-tut)
 
 ;;; skk-tut.el ends here
