@@ -1,6 +1,6 @@
 ;;; skk-xemacs.el --- XEmacs support for SKK -*- coding: iso-2022-jp -*-
 
-;; Copyright (C) 2000-2007 SKK Development Team <skk@ring.gr.jp>
+;; Copyright (C) 2000-2010 SKK Development Team <skk@ring.gr.jp>
 
 ;; Author: Tetsuo Tsukamoto <czkmt@remus.dti.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
@@ -34,7 +34,9 @@
 (eval-and-compile
   (require 'balloon-help)
   (require 'poe)
-  (require 'skk-macs))
+  (require 'skk-macs)
+  (autoload 'display-pixel-height "frame")
+  (autoload 'display-pixel-width "frame"))
 
 ;;;###autoload (unless (noninteractive) (require 'skk-setup))
 
@@ -90,6 +92,15 @@
     ["About Daredevil SKK..." skk-version t]
     ["Visit Daredevil SKK Web Site" skk-xemacs-visit-openlab t]))
 
+(defvar skk-tooltip-default-font-pixel-size 12)
+
+(defvar skk-xemacs-need-redraw-tooltip nil
+  "*Compiz $B2TF0;~$J$I%D!<%k%F%#%C%W$N2#I}$,$*$+$7$$$H$-$K@_Dj!#(B
+Non-nil $B$J$i$P%D!<%k%F%#%C%W$r:FIA2h$9$k!#(B")
+
+(defvar skk-xemacs-redraw-interval 0.01
+  "*$B%D!<%k%F%#%C%W:FIA2h$N:]$KCV$/;~4V!#(B")
+
 ;; Functions.
 
 (defun skk-xemacs-modeline-menu ()
@@ -134,7 +145,7 @@
 
 (defun skk-xemacs-visit-openlab ()
   (interactive)
-  (browse-url "http://openlab.ring.gr.jp/skk/index-j.html"))
+  (browse-url "http://openlab.jp/skk/index-j.html"))
 
 ;;;###autoload
 (defun skk-xemacs-prepare-modeline-properties ()
@@ -243,7 +254,8 @@
 	(max-lines
 	 ;; $B2hLL$NH>J,$N9b$5$r4p=`$K:GBg9b$r7h$a$k(B
 	 (- (/ (/ (display-pixel-height) 2)
-	       (cdr (assq 'PIXEL_SIZE (font-properties (face-font 'default)))))
+	       (or (cdr (assq 'PIXEL_SIZE (font-properties (face-font 'default))))
+		   skk-tooltip-default-font-pixel-size))
 	    2))
 	(columns 0)
 	(current-column nil))
@@ -433,7 +445,13 @@
 	(balloon-help-set-frame-properties)
 	(skk-xemacs-balloon-help-resize-help-frame listing)
 	(balloon-help-move-help-frame)
-	(balloon-help-expose-help-frame)))
+	(balloon-help-expose-help-frame)
+	(when skk-xemacs-need-redraw-tooltip
+	  ;; Compiz $B2TF0;~$K:FIA2h$7$J$$$H2#I}$,$*$+$7$/$J$k$3$H$"$j(B
+	  (sleep-for skk-xemacs-redraw-interval)
+	  (skk-tooltip-hide)
+	  (sleep-for skk-xemacs-redraw-interval)
+	  (balloon-help-expose-help-frame))))
     ;; Is this right?
     (setq balloon-help-timeout-id
 	  (add-timeout (/ balloon-help-timeout 1000.0)
@@ -441,7 +459,9 @@
 		       nil))))
 
 (defun skk-xemacs-balloon-help-resize-help-frame (&optional listing)
-  ;; $B=D$ND9$5$,9g$o$J$$$N$G!"9g$o$;$k!#(B
+  ;; GNU Emacs $B$H0c$$(B XEmacs $B$N(B balloon help $B$O%5%$%:$N<+F0D4@0$,(B
+  ;; $B$&$^$/8z$+$:!"J8;z$,7g$1$k$3$H$b$"$k$?$a!"$3$3$G=PMh$k$@$1(B
+  ;; $BD4@0$9$k!#(B
   (save-excursion
     (set-buffer balloon-help-buffer)
     (let* ((longest 0)
@@ -449,7 +469,11 @@
 	   (done nil)
 	   (inst (vector 'string ':data nil))
 	   (window (frame-selected-window balloon-help-frame))
-	   (font-width (font-width (face-font 'default) balloon-help-frame))
+	   (font-width (min (font-width (face-font 'default)
+					balloon-help-frame)
+			    (glyph-width (make-glyph "a") window)
+			    (/ (glyph-width (make-glyph "$B$"(B") window)
+			       2)))
 	   start width
 	   (window-min-height 1)
 	   (window-min-width 1))
@@ -461,18 +485,21 @@
 	(setq longest (max longest (glyph-width (make-glyph inst) window))
 	      done (not (= 0 (forward-line))))
 	(and (not done) (setq lines (1+ lines))))
-      (setq width (/ longest font-width)
-	    width (if (> longest (* width font-width)) (1+ width) width))
+      (setq width (round (/ (float longest) (float font-width))))
       ;; Increase width and lines...
-      (setq width (1+ width))
-      (setq lines (cond ((= lines 1)
-			 lines)
-			((or listing (= lines 2))
-			 (+ 1 lines))
-			(t
-			 (+ 1 lines))))
+      (when (<= width 10)
+	(setq width (+ (round (log (float width) 2)) width)))
+      (setq lines (cond
+		   ((= lines 1)
+		    lines)
+		   ((or listing (= lines 2))
+		    (+ 1 lines))
+		   (t
+		    (+ (max 1
+			    (round (/ (float lines) 10.0))) ; 1+ per 10 lines
+			    lines))))
       ;;
-      (set-frame-size balloon-help-frame (+ 0 width) lines))))
+      (set-frame-size balloon-help-frame width lines))))
 
 ;; Hooks.
 
@@ -512,9 +539,6 @@
 	   (delete-region (point) skk-henkan-start-point))
 	 (skk-kakutei))))
 
-(require 'product)
-(product-provide
-    (provide 'skk-xemacs)
-  (require 'skk-version))
+(provide 'skk-xemacs)
 
 ;;; skk-xemacs.el ends here
